package com.logicbig.uicommon;

import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

public class Throttler {
    private Timer timer;

    public Throttler(int rate, Runnable updater) {
        timer = new Timer(rate, new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                //this is already in EDT
                timer.stop();
                updater.run();
            }
        });
    }

    public void updateReceived() {
        //timer must be accessed by EDT  because actionPerformed is also invoked in EDT
        //otherwise we have to synchronized it. Not doing so might miss the events
        if (!SwingUtilities.isEventDispatchThread()) {
            throw new IllegalArgumentException("updateReceived() must be called in EDT");
        }

        if (!timer.isRunning()) {
            timer.restart();
        }
    }
}